CubePageView class

This Widget has the PageView widget inside. It works in two modes : 1 - Using the default constructor CubePageView passing the items in children property. 2 - Using the factory constructor CubePageView.builder passing a itemBuilder and itemCount properties.

Inheritance

Constructors

CubePageView({Key? key, ValueChanged<int>? onPageChanged, PageController? controller, required List<Widget>? children, Axis scrollDirection = Axis.horizontal, int startPage = 0, CubeTransformStyle transformStyle = CubeTransformStyle.outside})
Creates a scrollable list that works page by page from an explicit List of widgets.
const
CubePageView.builder({Key? key, required int? itemCount, required CubeWidgetBuilder? itemBuilder, ValueChanged<int>? onPageChanged, PageController? controller, Axis scrollDirection = Axis.horizontal, int startPage = 0, CubeTransformStyle transformStyle = CubeTransformStyle.outside})
Creates a scrollable list that works page by page using widgets that are created on demand.
const

Properties

children → List<Widget>?
Widgets you want to use inside the CubePageView, this is only required if you use CubePageView constructor
final
controller → PageController?
An object that can be used to control the position to which this page view is scrolled.
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → CubeWidgetBuilder?
Builder to customize your items
final
itemCount → int?
The number of items you have, this is only required if you use CubePageView.builder
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPageChanged → ValueChanged<int>?
Called whenever the page in the center of the viewport changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
Direction
final
startPage → int
Starting page
final
transformStyle → CubeTransformStyle
inside or outside
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CubePageViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited