CubeWidget class

This widget has the logic to do the 3D cube transformation It only should be used if you use CubePageView.builder

Inheritance

Constructors

CubeWidget({Key? key, required int index, required double pageNotifier, required Widget child, Axis rotationDirection = Axis.horizontal, bool centerAligned = false, CubeTransformStyle transformStyle = CubeTransformStyle.outside})
const

Properties

centerAligned → bool
sides are center-aligned, it looks not like a cube, but nice
final
child → Widget
Child you want to use inside the Cube
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
Index of the current item
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
pageNotifier → double
Page Notifier value, it comes from the CubeWidgetBuilder
final
rotationDirection → Axis
Rotation direction
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformStyle → CubeTransformStyle
inside or outside
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited